/*----------------------------------------------------------------------------
 * Name:    Blinky.c
 * Purpose: LED Flasher
 *----------------------------------------------------------------------------
 * This file is part of the uVision/ARM development tools.
 * This software may only be used under the terms of a valid, current,
 * end user licence from KEIL for a compatible version of KEIL software
 * development tools. Nothing else gives you the right to use this software.
 *
 * This software is supplied "AS IS" without warranties of any kind.
 *
 * Copyright (c) 2018 Keil - An ARM Company. All rights reserved.
 *----------------------------------------------------------------------------*/

#include <stdio.h>
#include "main.h"
#include "Board_LED.h"                  /* ::Board Support:LED     */
#include "Board_Buttons.h"              /* ::Board Support:Buttons */
#include "cmsis_os2.h"                  /* ::CMSIS:RTOS2           */
#include "RTE_Components.h"             /* Component selection     */
#include CMSIS_device_header

#ifdef RTE_Compiler_EventRecorder
#include "EventRecorder.h"
#endif

static osThreadId_t tid_thrLED;         /* Thread id of thread: LED */
static osThreadId_t tid_thrBUT;         /* Thread id of thread: BUT */

/*----------------------------------------------------------------------------
  thrLED: blink LED
 *----------------------------------------------------------------------------*/
__NO_RETURN static void thrLED(void *argument) {
  uint32_t led_max    = LED_GetCount();
  uint32_t led_num    = 0U;

  (void)argument;

  printf("thrLED is running\n");
  
  for (;;) {
    osThreadFlagsWait(0x0001U, osFlagsWaitAny ,osWaitForever);
    LED_On(led_num);                                           /* Turn specified LED on */    
    printf("Blink LED number %d\n", led_num);
    osThreadFlagsWait(0x0001U, osFlagsWaitAny ,osWaitForever);
    LED_Off(led_num);                                          /* Turn specified LED off */

    led_num++;                                                 /* Change LED number */
    if (led_num >= led_max) {
      led_num = 0U;                                            /* Restart with first LED */
    }
  }

}

/*----------------------------------------------------------------------------
  thrBUT: check button state
 *----------------------------------------------------------------------------*/
__NO_RETURN static void thrBUT(void *argument) {
  uint32_t button_msk = (1U << Buttons_GetCount()) - 1U;

  (void)argument;
  
  printf("thrBUT is running\n");

  for (;;) {
    osDelay(100U);                                             /* Wait */
    if (Buttons_GetState() & (button_msk)) printf("Button is pressed\n");
    while (Buttons_GetState() & (button_msk));                 /* Wait while holding user button */
    osThreadFlagsSet(tid_thrLED, 0x0001U);
  }

}

/*----------------------------------------------------------------------------
 * Application main thread
 *---------------------------------------------------------------------------*/
__NO_RETURN void app_main (void *argument) {

  (void)argument;

  LED_Initialize();                                            /* initialize LEDs */
  Buttons_Initialize();                                        /* initialize Buttons */

  tid_thrBUT = osThreadNew (thrBUT, NULL, NULL);               /* create BUT thread */
  if (tid_thrBUT == NULL) { /* add error handling */ }         

  tid_thrLED = osThreadNew (thrLED, NULL, NULL);               /* create LED thread */
  if (tid_thrLED == NULL) { /* add error handling */ }

  osThreadExit();
}
